@@ -20,7 +20,7 @@
 
 /**
  * SECTION:anjuta-preferences
- * @short_description: Anjuta Prefereces system.
+ * @short_description: Anjuta Preferences system.
  * @see_also: #AnjutaPreferencesDialog
  * @stability: Unstable
  * @include: libanjuta/anjuta-preferences.h
@@ -63,87 +63,19 @@
 /* AnjutaPreferences is a singleton */
 static AnjutaPreferences* default_preferences = NULL;
 
-struct _AnjutaProperty
-{
-	GtkWidget                *object;
-	gchar                    *key;
-	gchar                    *default_value;
-	gint                     notify_id;
-	GSettings				 *gsettings;
-
-	/* Set true if custom set/get to be used */
-	gboolean                  custom;
-
-	/* For custom objects */
-	void    (*set_property) (AnjutaProperty *prop, const gchar *value);
-	gchar * (*get_property) (AnjutaProperty *prop);
-
-};
-
 struct _AnjutaPreferencesPriv
 {
-	GHashTable          *properties;
 	GtkWidget           *prefs_dialog;
 	AnjutaPluginManager *plugin_manager;
-	gboolean             is_showing;
 
-	GHashTable			*notifications;
-};
-
-/* Internal structure for anjuta_preferences_foreach */
-struct _AnjutaPreferencesForeachData
-{
-	AnjutaPreferences *pr;
-	AnjutaPreferencesCallback callback;
-	gpointer callback_data;
+	gchar				*common_schema_id;
+	GHashTable			*common_gsettings;
 };
 
 #define PREFERENCE_PROPERTY_PREFIX "preferences"
 
 G_DEFINE_TYPE (AnjutaPreferences, anjuta_preferences, G_TYPE_OBJECT);
 
-static void
-property_destroy (AnjutaProperty *property)
-{
-	g_return_if_fail (property);
-	if (property->key) g_free (property->key);
-	if (property->default_value) g_free (property->default_value);
-	g_object_unref (property->object);
-	g_object_unref (property->gsettings);
-	g_free (property);
-}
-
-/**
- * anjuta_property_get_widget:
- * @prop: an #AnjutaProperty reference
- *
- * Gets the widget associated with the property.
- *
- * Returns: a #GtkWidget object associated with the property.
- */
-GtkWidget*
-anjuta_property_get_widget (AnjutaProperty *prop)
-{
-	return prop->object;
-}
-
-static void
-unregister_preferences_key (GtkWidget *widget,
-							gpointer user_data)
-{
-	AnjutaProperty *p;
-	AnjutaPreferences *pr;
-	gchar *key;
-
-	p = (AnjutaProperty *) user_data;
-	pr = g_object_get_data (G_OBJECT (widget),
-							"AnjutaPreferences");
-	key = g_strdup (p->key);
-
-	g_hash_table_remove (pr->priv->properties, key);
-	g_free (key);
-}
-
 static GVariant*
 string_to_gdkcolor (const GValue* value, const GVariantType* type, gpointer user_data)
 {
@@ -168,8 +100,7 @@ gdkcolor_to_string (GValue* value, GVariant* variant, gpointer user_data)
 static GVariant*
 active_to_string (const GValue* value, const GVariantType* type, gpointer user_data)
 {
-	AnjutaProperty* p = user_data;
-	GtkComboBox* combo = GTK_COMBO_BOX(p->object);
+	GtkComboBox* combo = GTK_COMBO_BOX(user_data);
 
 	return g_variant_new_string (gtk_combo_box_get_active_id (combo));
 }
@@ -177,8 +108,7 @@ active_to_string (const GValue* value, const GVariantType* type, gpointer user_d
 static gboolean
 string_to_active (GValue* value, GVariant* variant, gpointer user_data)
 {
-	AnjutaProperty* p = user_data;
-	GtkComboBox* combo = GTK_COMBO_BOX(p->object);
+	GtkComboBox* combo = GTK_COMBO_BOX(user_data);
 
 	gtk_combo_box_set_active_id (combo, g_variant_get_string (variant, NULL));
 	g_value_set_int (value, gtk_combo_box_get_active (combo));
@@ -189,99 +119,16 @@ string_to_active (GValue* value, GVariant* variant, gpointer user_data)
 static void
 update_file_property (GtkWidget* widget, gpointer user_data)
 {
-	AnjutaProperty* p = user_data;
-	gchar* text_value = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (p->object));
+	GtkFileChooser *chooser = GTK_FILE_CHOOSER (user_data);
+	GSettings *gsettings = g_object_get_data (G_OBJECT (chooser), "anjuta-bind-gsettings");
+	const gchar *key = g_object_get_data (G_OBJECT (chooser), "anjuta-bind-key");
+	gchar* text_value = gtk_file_chooser_get_filename (chooser);
 
-	g_settings_set_string (p->gsettings, p->key, text_value);
+	g_settings_set_string (gsettings, key, text_value);
 
 	g_free (text_value);
 }
 
-static gboolean
-connect_objects (AnjutaPreferences *pr, GSettings* settings, AnjutaProperty *p)
-{
-	gboolean ok = TRUE;
-
-	g_object_set_data (G_OBJECT (p->object), "AnjutaPreferences", pr);
-
-	/* Start with the most specialized widget as a GtkSpinButton
-	 * is a GtkEntry too */
-	if (GTK_IS_COLOR_BUTTON (p->object))
-	{
-		g_settings_bind_with_mapping (settings, p->key,
-								 p->object, "color",
-								 G_SETTINGS_BIND_DEFAULT,
-								 gdkcolor_to_string,
-								 string_to_gdkcolor,
-								 p,
-								 NULL);
-	}
-	else if (GTK_IS_FONT_BUTTON (p->object))
-	{
-		g_settings_bind (settings, p->key, p->object, "font-name",
-		                 G_SETTINGS_BIND_DEFAULT);
-	}
-	else if (GTK_IS_SPIN_BUTTON (p->object))
-	{
-		g_settings_bind (settings, p->key, p->object, "value",
-		                 G_SETTINGS_BIND_DEFAULT);
-	}
-	else if (GTK_IS_FILE_CHOOSER_BUTTON (p->object))
-	{
-		gchar *filename;
-
-		switch (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (p->object)))
-		{
-		case GTK_FILE_CHOOSER_ACTION_OPEN:
-		case GTK_FILE_CHOOSER_ACTION_SAVE:
-			filename = g_settings_get_string (p->gsettings, p->key);
-			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (p->object),
-										 		 filename);
-			g_free (filename);
-			g_signal_connect (G_OBJECT(p->object), "file-set",
-							  G_CALLBACK (update_file_property), p);
-			break;
-		case GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER:
-		case GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER:
-			filename = g_settings_get_string (p->gsettings, p->key);
-			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (p->object),
-			                                     filename);
-			g_free (filename);
-			g_signal_connect (G_OBJECT(p->object), "current-folder-changed",
-							  G_CALLBACK (update_file_property), p);
-			break;
-		default:
-			ok = FALSE;
-		}
-	}
-	else if (GTK_IS_COMBO_BOX (p->object))
-	{
-		g_settings_bind_with_mapping (settings, p->key,
-								 p->object, "active",
-								 G_SETTINGS_BIND_DEFAULT,
-								 string_to_active,
-								 active_to_string,
-								 p,
-								 NULL);
-	}
-	else if (GTK_IS_CHECK_BUTTON (p->object))
-	{
-		g_settings_bind (settings, p->key, p->object, "active",
-		                 G_SETTINGS_BIND_DEFAULT);
-	}
-	else if (GTK_IS_ENTRY (p->object))
-	{
-		g_settings_bind (settings, p->key, p->object, "text",
-		                 G_SETTINGS_BIND_DEFAULT);
-	}
-	else
-	{
-		ok = FALSE;
-	}
-
-	return ok;
-}
-
 /**
  * anjuta_preferences_register_property:
  * @pr: a #AnjutaPreferences object
@@ -301,26 +148,92 @@ anjuta_preferences_register_property (AnjutaPreferences *pr,
                                       GtkWidget *object,
                                       const gchar *key)
 {
-	AnjutaProperty *p;
+	gboolean ok = TRUE;
 
 	g_return_val_if_fail (ANJUTA_IS_PREFERENCES (pr), FALSE);
 	g_return_val_if_fail (GTK_IS_WIDGET (object), FALSE);
 	g_return_val_if_fail (strlen(key) > 0, FALSE);
 
-	p = g_new0 (AnjutaProperty, 1);
-	p->object = g_object_ref (object);
-	p->key = g_strdup (key);
-	p->gsettings = g_object_ref (settings);
+	/* Start with the most specialized widget as a GtkSpinButton
+	 * is a GtkEntry too */
+	if (GTK_IS_COLOR_BUTTON (object))
+	{
+		g_settings_bind_with_mapping (settings, key,
+								 object, "color",
+								 G_SETTINGS_BIND_DEFAULT,
+								 gdkcolor_to_string,
+								 string_to_gdkcolor,
+								 object,
+								 NULL);
+	}
+	else if (GTK_IS_FONT_BUTTON (object))
+	{
+		g_settings_bind (settings, key, object, "font-name",
+		                 G_SETTINGS_BIND_DEFAULT);
+	}
+	else if (GTK_IS_SPIN_BUTTON (object))
+	{
+		g_settings_bind (settings, key, object, "value",
+		                 G_SETTINGS_BIND_DEFAULT);
+	}
+	else if (GTK_IS_FILE_CHOOSER_BUTTON (object))
+	{
+		gchar *filename;
 
-	p->custom = FALSE;
-	p->set_property = NULL;
-	p->get_property = NULL;
+		switch (gtk_file_chooser_get_action (GTK_FILE_CHOOSER (object)))
+		{
+		case GTK_FILE_CHOOSER_ACTION_OPEN:
+		case GTK_FILE_CHOOSER_ACTION_SAVE:
+			filename = g_settings_get_string (settings, key);
+			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (object),
+										 		 filename);
+			g_free (filename);
+			g_object_set_data_full (G_OBJECT (object), "anjuta-bind-gsettings", g_object_ref (settings), (GDestroyNotify)g_object_unref);
+			g_object_set_data_full (G_OBJECT (object), "anjuta-bind-key", g_strdup (key), (GDestroyNotify)g_free);
+			g_signal_connect (G_OBJECT (object), "file-set",
+							  G_CALLBACK (update_file_property), object);
+			break;
+		case GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER:
+		case GTK_FILE_CHOOSER_ACTION_CREATE_FOLDER:
+			filename = g_settings_get_string (settings, key);
+			gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (object),
+			                                     filename);
+			g_free (filename);
+			g_object_set_data_full (G_OBJECT (object), "anjuta-bind-gsettings", g_object_ref (settings), (GDestroyNotify)g_object_unref);
+			g_object_set_data_full (G_OBJECT (object), "anjuta-bind-key", g_strdup (key), (GDestroyNotify)g_free);
+			g_signal_connect (G_OBJECT(object), "current-folder-changed",
+							  G_CALLBACK (update_file_property), object);
+			break;
+		default:
+			ok = FALSE;
+		}
+	}
+	else if (GTK_IS_COMBO_BOX (object))
+	{
+		g_settings_bind_with_mapping (settings, key,
+								 object, "active",
+								 G_SETTINGS_BIND_DEFAULT,
+								 string_to_active,
+								 active_to_string,
+								 object,
+								 NULL);
+	}
+	else if (GTK_IS_CHECK_BUTTON (object))
+	{
+		g_settings_bind (settings, key, object, "active",
+		                 G_SETTINGS_BIND_DEFAULT);
+	}
+	else if (GTK_IS_ENTRY (object))
+	{
+		g_settings_bind (settings, key, object, "text",
+		                 G_SETTINGS_BIND_DEFAULT);
+	}
+	else
+	{
+		ok = FALSE;
+	}
 
-	g_hash_table_insert (pr->priv->properties, g_strdup (key), p);
-	g_signal_connect (G_OBJECT (p->object), "destroy",
-	                  G_CALLBACK (unregister_preferences_key),
-	                  p);
-	return connect_objects (pr, settings, p);
+	return ok;
 }
 
 /**
@@ -353,6 +266,7 @@ anjuta_preferences_register_all_properties_from_builder_xml (AnjutaPreferences *
 		const gchar *ptr;
 		GtkWidget *widget, *p;
 		gboolean cont_flag = FALSE;
+		GSettings *key_settings = settings;
 
 		if (!GTK_IS_WIDGET (node->data) || !GTK_IS_BUILDABLE (node->data))
 			continue;
@@ -376,6 +290,32 @@ anjuta_preferences_register_all_properties_from_builder_xml (AnjutaPreferences *
 		}
 		if (*key == '\0') continue;
 
+		/* Check if we need to use common settings */
+		if (*key == '.')
+		{
+			const gchar *id = strrchr (key, '.');
+			GString *schema_id;
+
+			schema_id = g_string_new (pr->priv->common_schema_id);
+			if (key != id)
+			{
+				g_string_append_len (schema_id, key, id - key);
+			}
+			key = id + 1;
+
+			key_settings = (GSettings *)g_hash_table_lookup (pr->priv->common_gsettings, schema_id->str);
+			if (key_settings == NULL)
+			{
+				key_settings = g_settings_new (schema_id->str);
+				g_hash_table_insert (pr->priv->common_gsettings, schema_id->str, key_settings);
+				g_string_free (schema_id, FALSE);
+			}
+			else
+			{
+				g_string_free (schema_id, TRUE);
+			}
+		}
+
 		/* Added only if it's a descendant child of the parent */
 		p = gtk_widget_get_parent (widget);
 		while (p != parent)
@@ -390,7 +330,7 @@ anjuta_preferences_register_all_properties_from_builder_xml (AnjutaPreferences *
 		if (cont_flag)
 			continue;
 
-		if (!anjuta_preferences_register_property (pr, settings, widget, key))
+		if (!anjuta_preferences_register_property (pr, key_settings, widget, key))
 		{
 			g_critical ("Invalid preference widget named %s, check anjuta_preferences_add_page function documentation.", name);
 		}
@@ -415,9 +355,11 @@ anjuta_preferences_register_all_properties_from_builder_xml (AnjutaPreferences *
  * widget names of the form:
  *
  * <programlisting>
- *     preferences(_.*)?:PROPERTYKEY
+ *     preferences(_.*)?:(.SCHEMAID)?PROPERTYKEY
  *     where,
- *       PROPERTYKEY is the property key. e.g - 'tab.size'.
+ *       SCHEMAID if present the key will be added not in the page settings but
+ *                in common settings using SCHEMAID as a suffix.
+ *       PROPERTYKEY is the property key. e.g - 'tab-size'.
  * </programlisting>
  *
  * The widget must derivated from one of the following Gtk widget:
@@ -583,26 +525,19 @@ anjuta_preferences_dispose (GObject *obj)
 {
 	AnjutaPreferences *pr = ANJUTA_PREFERENCES (obj);
 
-	if (pr->priv->properties)
+	if (pr->priv->common_gsettings)
 	{
-		/* This will release the refs on property objects */
-		g_hash_table_destroy (pr->priv->properties);
-		pr->priv->properties = NULL;
+		g_hash_table_destroy (pr->priv->common_gsettings);
+		pr->priv->common_gsettings = NULL;
 	}
+	g_free (pr->priv->common_schema_id);
+	pr->priv->common_schema_id = NULL;
 }
 
 static void
 anjuta_preferences_init (AnjutaPreferences *pr)
 {
 	pr->priv = g_new0 (AnjutaPreferencesPriv, 1);
-
-	pr->priv->properties = g_hash_table_new_full (g_str_hash, g_str_equal,
-												  g_free,
-												  (GDestroyNotify) property_destroy);
-	pr->priv->notifications = g_hash_table_new_full (g_int_hash,
-	                                                 g_int_equal,
-	                                                 NULL,
-	                                                 g_free);
 }
 
 static void
@@ -629,13 +564,14 @@ anjuta_preferences_class_init (AnjutaPreferencesClass *class)
 /**
  * anjuta_preferences_new:
  * @plugin_manager: #AnjutaPluginManager to be used
+ * @common_schema_id: Common schema id used for key starting with .
  *
  * Creates a new #AnjutaPreferences object
  *
  * Return value: A #AnjutaPreferences object.
  */
 AnjutaPreferences *
-anjuta_preferences_new (AnjutaPluginManager *plugin_manager)
+anjuta_preferences_new (AnjutaPluginManager *plugin_manager, const gchar *common_schema_id)
 {
 	AnjutaPreferences *pr;
 
@@ -643,6 +579,10 @@ anjuta_preferences_new (AnjutaPluginManager *plugin_manager)
 	{
 		pr = g_object_new (ANJUTA_TYPE_PREFERENCES, NULL);
 		pr->priv->plugin_manager = g_object_ref (plugin_manager);
+		pr->priv->common_schema_id = g_strdup (common_schema_id);
+		pr->priv->common_gsettings = g_hash_table_new_full (g_str_hash, g_str_equal,
+		                                                    g_free,
+		                                                    (GDestroyNotify) g_object_unref);
 		default_preferences = pr;
 		return pr;
 	}
