@@ -27,6 +27,7 @@
 #include "amp-group.h"
 
 #include "amp-node.h"
+#include "amp-source.h"
 #include "am-scanner.h"
 #include "am-properties.h"
 #include "am-writer.h"
@@ -340,6 +341,76 @@ on_group_monitor_changed (GFileMonitor *monitor,
 	}
 }
 
+void
+amp_group_node_update_preset_variable (AmpGroupNode *group)
+{
+	gchar *path;
+	AnjutaToken *value;
+	AmpVariable *var;
+	GFile *root;
+	GFile *file;
+	AnjutaProjectNode *node;
+
+	if (group->preset_token != NULL) anjuta_token_free (group->preset_token);
+	group->preset_token = anjuta_token_new_static (ANJUTA_TOKEN_FILE,  NULL);
+
+	/* Get project root */
+	for (node = ANJUTA_PROJECT_NODE (group); anjuta_project_node_parent (node) != NULL; node = anjuta_project_node_parent (node));
+	root = anjuta_project_node_get_file (node);
+
+	/* Set source directory variables */
+	file = anjuta_project_node_get_file (group);
+	value = anjuta_token_insert_token_list (FALSE, NULL,
+	                                  ANJUTA_TOKEN_LIST, NULL,
+	                                  ANJUTA_TOKEN_ARGUMENT, NULL,
+	                                  ANJUTA_TOKEN_CONTENT, ".",
+	                                  NULL);
+	anjuta_token_append_child (group->preset_token, value);
+	var = amp_variable_new ("srcdir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+	var = amp_variable_new ("builddir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+
+	path = g_file_get_path (file);
+	value = anjuta_token_insert_token_list (FALSE, NULL,
+	                                  ANJUTA_TOKEN_LIST, NULL,
+	                                  ANJUTA_TOKEN_ARGUMENT, NULL,
+	                                  ANJUTA_TOKEN_CONTENT, path,
+	                                  NULL);
+	g_free (path);
+	anjuta_token_append_child (group->preset_token, value);
+	var = amp_variable_new ("abs_srcdir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+	var = amp_variable_new ("abs_builddir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+
+	path = get_relative_path (file, root);
+	value = anjuta_token_insert_token_list (FALSE, NULL,
+	                                  ANJUTA_TOKEN_LIST, NULL,
+	                                  ANJUTA_TOKEN_ARGUMENT, NULL,
+	                                  ANJUTA_TOKEN_CONTENT, path,
+	                                  NULL);
+	g_free (path);
+	anjuta_token_append_child (group->preset_token, value);
+	var = amp_variable_new ("top_srcdir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+	var = amp_variable_new ("top_builddir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+
+	path = g_file_get_path (root);
+	value = anjuta_token_insert_token_list (FALSE, NULL,
+	                                  ANJUTA_TOKEN_LIST, NULL,
+	                                  ANJUTA_TOKEN_ARGUMENT, NULL,
+	                                  ANJUTA_TOKEN_CONTENT, path,
+	                                  NULL);
+	g_free (path);
+	anjuta_token_append_child (group->preset_token, value);
+	var = amp_variable_new ("abs_top_srcdir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+	var = amp_variable_new ("abs_top_builddir", 0, value);
+	g_hash_table_insert (group->variables, var->name, var);
+}
+
 AnjutaTokenFile*
 amp_group_node_set_makefile (AmpGroupNode *group, GFile *makefile, AmpProject *project)
 {
@@ -349,13 +420,18 @@ amp_group_node_set_makefile (AmpGroupNode *group, GFile *makefile, AmpProject *p
 	{
 		AnjutaToken *token;
 		AmpAmScanner *scanner;
+		AnjutaProjectNode *source;
 
 		group->makefile = g_object_ref (makefile);
 		group->tfile = anjuta_token_file_new (makefile);
+		source = amp_source_node_new (makefile, ANJUTA_PROJECT_PROJECT | ANJUTA_PROJECT_FRAME | ANJUTA_PROJECT_READ_ONLY);
+		anjuta_project_node_append (ANJUTA_PROJECT_NODE (group), source);
 
 		token = anjuta_token_file_load (group->tfile, NULL);
 		amp_project_add_file (project, makefile, group->tfile);
 
+		amp_group_node_update_preset_variable (group);
+
 		scanner = amp_am_scanner_new (project, group);
 		group->make_token = amp_am_scanner_parse_token (scanner, anjuta_token_new_static (ANJUTA_TOKEN_FILE, NULL), token, makefile, NULL);
 		amp_am_scanner_free (scanner);
@@ -431,6 +507,11 @@ amp_group_node_update_node (AmpGroupNode *group, AmpGroupNode *new_group)
 		g_object_unref (group->makefile);
 		group->monitor = NULL;
 	}
+	if (group->preset_token != NULL)
+	{
+		anjuta_token_free (group->preset_token);
+		group->preset_token = NULL;
+	}
 	if (group->tfile) anjuta_token_file_free (group->tfile);
 	for (i = 0; i < AM_GROUP_TOKEN_LAST; i++)
 	{
@@ -445,6 +526,8 @@ amp_group_node_update_node (AmpGroupNode *group, AmpGroupNode *new_group)
 	new_group->tfile = NULL;
 	group->make_token = new_group->make_token;
 	new_group->make_token = NULL;
+	group->preset_token = new_group->preset_token;
+	new_group->preset_token = NULL;
 	memcpy (group->tokens, new_group->tokens, sizeof (group->tokens));
 	memset (new_group->tokens, 0, sizeof (new_group->tokens));
 	hash = group->variables;
@@ -515,12 +598,13 @@ amp_group_node_set_file (AmpGroupNode *group, GFile *new_file)
 }
 
 AmpGroupNode*
-amp_group_node_new (GFile *file, gboolean dist_only)
+amp_group_node_new (GFile *file, const gchar *name, gboolean dist_only)
 {
 	AmpGroupNode *node = NULL;
 
 	node = g_object_new (AMP_TYPE_GROUP_NODE, NULL);
 	node->base.file = g_object_ref (file);
+	node->base.name = g_strdup (name);
 	node->dist_only = dist_only;
 	memset (node->tokens, 0, sizeof (node->tokens));
 
@@ -528,12 +612,9 @@ amp_group_node_new (GFile *file, gboolean dist_only)
 }
 
 AmpGroupNode*
-amp_group_node_new_valid (GFile *file, gboolean dist_only, GError **error)
+amp_group_node_new_valid (GFile *file, const gchar *name, gboolean dist_only, GError **error)
 {
-	gchar *name;
-
 	/* Validate group name */
-	name = g_file_get_basename (file);
 	if (!name || strlen (name) <= 0)
 	{
 		g_free (name);
@@ -545,20 +626,19 @@ amp_group_node_new_valid (GFile *file, gboolean dist_only, GError **error)
 		gboolean failed = FALSE;
 		const gchar *ptr = name;
 		while (*ptr) {
-			if (!isalnum (*ptr) && (strchr ("#$:%+,-.=@^_`~", *ptr) == NULL))
+			if (!isalnum (*ptr) && (strchr ("#$:%+,-.=@^_`~/", *ptr) == NULL))
 				failed = TRUE;
 			ptr++;
 		}
 		if (failed) {
 			g_free (name);
 			error_set (error, IANJUTA_PROJECT_ERROR_VALIDATION_FAILED,
-			           _("Group name can only contain alphanumeric or \"#$:%+,-.=@^_`~\" characters"));
+			           _("Group name can only contain alphanumeric or \"#$:%+,-.=@^_`~/\" characters"));
 			return NULL;
 		}
 	}
-	g_free (name);
 
-	return amp_group_node_new (file, dist_only);
+	return amp_group_node_new (file, name, dist_only);
 }
 
 void
@@ -591,10 +671,23 @@ amp_group_node_save (AmpNode *group, AmpNode *parent, AmpProject *project, GErro
 	AnjutaTokenFile *tfile;
 	AnjutaProjectNode *child;
 	gboolean ok = TRUE;
+	GFile *directory;
+
+	/* Create directory */
+	directory = g_file_get_parent (AMP_GROUP_NODE (group)->makefile);
+	g_file_make_directory (directory, NULL, NULL);
+	g_object_unref (directory);
 
 	/* Save group */
 	tfile = AMP_GROUP_NODE (group)->tfile;
-	if (tfile == NULL) return FALSE;
+	if (tfile == NULL)
+	{
+		/* Create an empty makefile */
+		g_file_replace_contents (AMP_GROUP_NODE (group)->makefile, "", 0, NULL, FALSE, G_FILE_CREATE_NONE, NULL, NULL, NULL);
+
+		return TRUE;
+	}
+
 	if (anjuta_token_file_is_dirty (tfile))
 	{
 		if (!anjuta_token_file_save (tfile, error)) return FALSE;
@@ -653,6 +746,7 @@ amp_group_node_init (AmpGroupNode *node)
 	node->variables = g_hash_table_new_full (g_str_hash, g_str_equal, NULL, (GDestroyNotify)amp_variable_free);
 	node->monitor = NULL;
 	memset (node->tokens, 0, sizeof (node->tokens));
+	node->preset_token = NULL;
 }
 
 static void
@@ -663,6 +757,9 @@ amp_group_node_dispose (GObject *object)
 	if (node->monitor) g_object_unref (node->monitor);
 	node->monitor = NULL;
 
+	if (node->preset_token) anjuta_token_free (node->preset_token);
+	node->preset_token = NULL;
+
 	G_OBJECT_CLASS (amp_group_node_parent_class)->dispose (object);
 }
 
