@@ -32,11 +32,12 @@
 #include "property.h"
 #include "parser.h"
 #include "install.h"
-#include "autogen.h"
 
 #include <libanjuta/anjuta-debug.h>
 #include <libanjuta/anjuta-utils.h>
+#include <libanjuta/anjuta-autogen.h>
 #include <libanjuta/interfaces/ianjuta-wizard.h>
+#include <libanjuta/interfaces/ianjuta-editor.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <glib.h>
@@ -56,6 +57,13 @@
 #define ANJUTA_PROJECT_DIRECTORY_PROPERTY "AnjutaProjectDirectory"
 #define USER_NAME_PROPERTY "UserName"
 #define EMAIL_ADDRESS_PROPERTY "EmailAddress"
+#define INDENT_WIDTH_PROPERTY "IndentWidth"
+#define TAB_WIDTH_PROPERTY "TabWidth"
+#define USE_TABS_PROPERTY "UseTabs"
+
+/* Common editor preferences */
+#define ANJUTA_PREF_SCHEMA_PREFIX "org.gnome.anjuta."
+
 
 /* Widget and signal name found in glade file
  *---------------------------------------------------------------------------*/
@@ -111,7 +119,7 @@ struct _NPWDruid
 	NPWPageParser* parser;
 	GList* header_list;
 	NPWHeader* header;
-	NPWAutogen* gen;
+	AnjutaAutogen* gen;
 	gboolean busy;
 };
 
@@ -382,7 +390,7 @@ npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 	/* Remove all previous data */
 	gtk_notebook_remove_page(druid->project_book, 0);
 	npw_header_list_free (druid->header_list);
-	npw_autogen_clear_library_path (druid->gen);
+	anjuta_autogen_clear_library_path (druid->gen);
 
 	/* Create list of projects */
 	druid->header_list = npw_header_list_new ();
@@ -393,7 +401,7 @@ npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 		 * other directories can still be used to get included
 		 * files */
 		npw_header_list_readdir (&druid->header_list, directory);
-		npw_autogen_set_library_path (druid->gen, directory);
+		anjuta_autogen_set_library_path (druid->gen, directory);
 	}
 
 	dir = g_build_filename (g_get_user_data_dir (), "anjuta", "project", NULL);
@@ -404,7 +412,7 @@ npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 	 	* the first template read override the others */
 		npw_header_list_readdir (&druid->header_list, dir);
 	}
-	npw_autogen_set_library_path (druid->gen, dir);
+	anjuta_autogen_set_library_path (druid->gen, dir);
 	g_free (dir);
 
 	for (sys_dir = g_get_system_data_dirs (); *sys_dir != NULL; sys_dir++)
@@ -415,7 +423,7 @@ npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 			/* Read project template in system directory */
 			npw_header_list_readdir (&druid->header_list, dir);
 		}
-		npw_autogen_set_library_path (druid->gen, dir);
+		anjuta_autogen_set_library_path (druid->gen, dir);
 		g_free (dir);
 	}
 
@@ -424,7 +432,7 @@ npw_druid_fill_selection_page (NPWDruid* druid, const gchar *directory)
 		/* Read anjuta installation directory */
 		npw_header_list_readdir (&druid->header_list, PROJECT_WIZARD_DIRECTORY);
 	}
-	npw_autogen_set_library_path (druid->gen, PROJECT_WIZARD_DIRECTORY);
+	anjuta_autogen_set_library_path (druid->gen, PROJECT_WIZARD_DIRECTORY);
 
 	if (g_list_length (druid->header_list) == 0)
 	{
@@ -828,7 +836,7 @@ on_project_wizard_key_press_event(GtkWidget *widget, GdkEventKey *event,
 }
 
 static void
-on_druid_get_new_page (NPWAutogen* gen, gpointer data)
+on_druid_get_new_page (AnjutaAutogen* gen, gpointer data)
 {
 	NPWDruid* druid = (NPWDruid *)data;
 	gint current;
@@ -1034,7 +1042,7 @@ on_druid_real_prepare (GtkAssistant* assistant, GtkWidget *page, NPWDruid* druid
 
 				/* Change project */
 				druid->project_file = new_project;
-				npw_autogen_set_input_file (druid->gen, druid->project_file, "[+","+]");
+				anjuta_autogen_set_input_file (druid->gen, druid->project_file, "[+","+]");
 
 			}
 		}
@@ -1057,9 +1065,9 @@ on_druid_real_prepare (GtkAssistant* assistant, GtkWidget *page, NPWDruid* druid
 				npw_page_parser_free (druid->parser);
 			druid->parser = npw_page_parser_new (npw_druid_add_new_page (druid), druid->project_file, previous);
 
-			npw_autogen_set_output_callback (druid->gen, on_druid_parse_page, druid->parser);
-			npw_autogen_write_definition_file (druid->gen, druid->values);
-			npw_autogen_execute (druid->gen, on_druid_get_new_page, druid, NULL);
+			anjuta_autogen_set_output_callback (druid->gen, on_druid_parse_page, druid->parser, NULL);
+			anjuta_autogen_write_definition_file (druid->gen, druid->values, NULL);
+			anjuta_autogen_execute (druid->gen, on_druid_get_new_page, druid, NULL);
 		}
 		else
 		{
@@ -1120,7 +1128,7 @@ on_druid_finish (GtkAssistant* assistant, NPWDruid* druid)
 	inst = npw_install_new (druid->plugin);
 	npw_install_set_property (inst, druid->values);
 	npw_install_set_wizard_file (inst, npw_header_get_filename (druid->header));
-	for (path = g_list_last (npw_autogen_get_library_paths (druid->gen)); path != NULL; path = g_list_previous (path))
+	for (path = g_list_last (anjuta_autogen_get_library_paths (druid->gen)); path != NULL; path = g_list_previous (path))
 	{
 		npw_install_set_library_path (inst, (const gchar *)path->data);
 	}
@@ -1202,28 +1210,38 @@ npw_druid_create_assistant (NPWDruid* druid, const gchar *directory)
 static void
 npw_druid_add_default_property (NPWDruid* druid)
 {
-	NPWValue* value;
 	gchar* s;
-	/* gchar* email; */
 	AnjutaPreferences* pref;
+	GSettings *settings;
+	gboolean flag;
+	gint i;
 
 	pref = anjuta_shell_get_preferences (ANJUTA_PLUGIN (druid->plugin)->shell, NULL);
 
 	/* Add default base project directory */
-	value = npw_value_heap_find_value (druid->values, ANJUTA_PROJECT_DIRECTORY_PROPERTY);
-	npw_value_set_value (value, g_get_home_dir (), NPW_VALID_VALUE);
+	g_hash_table_insert (druid->values, g_strdup (ANJUTA_PROJECT_DIRECTORY_PROPERTY), g_strdup (g_get_home_dir()));
 
 	/* Add user name */
-	value = npw_value_heap_find_value (druid->values, USER_NAME_PROPERTY);
-	s = (gchar *)g_get_real_name();
-	npw_value_set_value (value, s, NPW_VALID_VALUE);
-	/* Add Email address */
-	value = npw_value_heap_find_value (druid->values, EMAIL_ADDRESS_PROPERTY);
+	g_hash_table_insert (druid->values, g_strdup (USER_NAME_PROPERTY), g_strdup (g_get_real_name()));
 
+	/* Add Email address */
 	/* FIXME: We need a default way for the mail */
 	s = anjuta_util_get_user_mail();
-	npw_value_set_value (value, s, NPW_VALID_VALUE);
-	g_free (s);
+	g_hash_table_insert (druid->values, g_strdup (EMAIL_ADDRESS_PROPERTY), s);
+
+	/* Add use-tabs property */
+	settings = g_settings_new (ANJUTA_PREF_SCHEMA_PREFIX IANJUTA_EDITOR_PREF_SCHEMA);
+	flag = g_settings_get_boolean (settings, IANJUTA_EDITOR_USE_TABS_KEY);
+	g_hash_table_insert (druid->values, g_strdup (USE_TABS_PROPERTY), g_strdup (flag ? "1" : "0"));
+
+	/* Add tab-width property */
+	i = g_settings_get_int (settings, IANJUTA_EDITOR_TAB_WIDTH_KEY);
+	g_hash_table_insert (druid->values, g_strdup (TAB_WIDTH_PROPERTY), g_strdup_printf("%d", i));
+
+	/* Add indent-width property */
+	i = g_settings_get_int (settings, IANJUTA_EDITOR_INDENT_WIDTH_KEY);
+	g_hash_table_insert (druid->values, g_strdup (INDENT_WIDTH_PROPERTY), g_strdup_printf("%d", i));
+	g_object_unref (settings);
 }
 
 /* Druid public functions
@@ -1235,7 +1253,7 @@ npw_druid_new (NPWPlugin* plugin, const gchar *directory)
 	NPWDruid* druid;
 
 	/* Check if autogen is present */
-	if (!npw_check_autogen())
+	if (!anjuta_check_autogen())
 	{
 		anjuta_util_dialog_error (NULL, _("Could not find autogen version 5; please install the autogen package. You can get it from http://autogen.sourceforge.net."));
 		return NULL;
@@ -1246,8 +1264,8 @@ npw_druid_new (NPWPlugin* plugin, const gchar *directory)
 	druid->project_file = NULL;
 	druid->busy = FALSE;
 	druid->page_list = g_queue_new ();
-	druid->values = npw_value_heap_new ();
-	druid->gen = npw_autogen_new ();
+	druid->values = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify)g_free);
+	druid->gen = anjuta_autogen_new ();
 	druid->plugin = plugin;
 	druid->error_extra_widget = NULL;
 
@@ -1277,8 +1295,8 @@ npw_druid_free (NPWDruid* druid)
 		npw_page_free (page);
 	}
 	g_queue_free (druid->page_list);
-	npw_value_heap_free (druid->values);
-	npw_autogen_free (druid->gen);
+	g_hash_table_destroy (druid->values);
+	g_object_unref (G_OBJECT (druid->gen));
 	if (druid->parser != NULL) npw_page_parser_free (druid->parser);
 	npw_header_list_free (druid->header_list);
 	gtk_widget_destroy (GTK_WIDGET (druid->window));
